@@ -131,6 +131,60 @@ bool Config_read(volatile Config *self, FILE* in) {
   return true;
 }
 
+//------------------------------------------------------------------------------
+
+bool Config_install_fallback(volatile Config *self) {
+
+  Binding *binding;
+  Command *command;  
+
+  Config_add_string(self, "       keyman64 version 1.3 ready             using fallback configuration            press ``b to enter bootloader      ");
+
+  command = Command_new();
+  command->action = ACTION_TYPE;
+  command->mask = 0;
+  command->data = 0;
+  
+  binding = Binding_new();
+  binding->key = 0x32;
+  Binding_add(binding, command);
+  
+  Config_add_binding(self, binding);
+  
+  command = Command_new();
+  command->action = ACTION_BOOT;
+
+  binding = Binding_new();
+  binding->key = 0x23;
+  Binding_add(binding, command);
+  
+  Config_add_binding(self, binding);
+
+  binding = Binding_new();
+  binding->key = 0x2a;
+
+  for(int i=0; i<5; i++) {
+    command = Command_new();
+    command->action = ACTION_KEY_PRESS;
+    command->data = 0x25;
+
+    Binding_add(binding, command);
+
+    command = Command_new();
+    command->action = ACTION_SLEEP_SHORT;
+    command->mask = 0xe8;
+    command->data = 0x03;
+
+    Binding_add(binding, command);
+  }
+
+  Config_add_binding(self, binding);
+  
+  return true;
+}
+
+//------------------------------------------------------------------------------
+
 void Config_free(Config *self) {
   for(int i=0; i<self->num_bindings; i++) {
     Binding_free(self->bindings[i]);
@@ -243,3 +297,4 @@ void State_free(State* self) {
 }
 
 //------------------------------------------------------------------------------
+
