@@ -238,6 +238,17 @@ static bool equal(const char *a, const char *b) {
   return strcasecmp(a, b) == 0;
 }
 
+//------------------------------------------------------------------------------
+
+static bool isSymbol(char *name) {
+    for(int i=0; i<sizeof(symbols)/sizeof(Symbol); i++) {
+      if(strcasecmp(symbols[i].name, name) == 0) {
+        return true;
+      }
+    }
+    return false;
+}
+
 //------------------------------------------------------------------------------
 // Functions for parsing config files
 //------------------------------------------------------------------------------
@@ -247,9 +258,13 @@ bool Config_parse(Config* self, FILE* in) {
   char* buffer = (char*) calloc(4096, sizeof(char));
   char* line;
   char* colon;
+  char* equals;
+  char* name;
+  char* value;
   char *keyspec;
   char *comment;
   int pos = 0;
+  int trailing = 0;
   
   Binding* binding;
   Command* command;
@@ -260,7 +275,7 @@ bool Config_parse(Config* self, FILE* in) {
   while(fgets(buffer, 4096, in) != NULL) {
     line = buffer;
     pos++;
-    
+
     // skip leading whitespace
     line += strspn(line, ws);
 
@@ -281,6 +296,32 @@ bool Config_parse(Config* self, FILE* in) {
       line[strlen(line)-1] = '\0';
     }
 
+    // check if this command is a definition
+    if((equals = strstr(line, "=")) != NULL) {
+      name = line;
+      equals[0] = '\0';      
+
+      if((trailing = strcspn(name, ws)) > 0) {
+        name[trailing] = '\0';
+      }
+
+      value = equals+1;
+      value += strspn(value, ws);
+      
+      if(StringList_has_definition(name)) {
+        fprintf(stderr, "error: line %d: '%s': symbol already defined\n", pos, name);
+        return false;
+      }
+
+      if(isSymbol(name)) {
+        fprintf(stderr, "error: line %d: '%s': symbol is a reserved key name\n", pos, name);
+        return false;
+      }                     
+      
+      StringList_add_definition(name, value);
+      continue;
+    }
+    
     // check if this command shall be bound to a key
     if((colon = strstr(line, ":")) != NULL) {
       keyspec = line;
@@ -289,7 +330,7 @@ bool Config_parse(Config* self, FILE* in) {
 
       // try to parse the keyspec...
       if(!Key_parse(&key, keyspec, false)) {
-        fprintf(stderr, "error: line %d: '%s': invalid key specification\n", pos, keyspec);
+        fprintf(stderr, "error: line %d: '%s': invalid key or slot specification\n", pos, keyspec);
         return false;
       }
     }
@@ -345,6 +386,12 @@ bool Key_parse(uint8_t *key, char* spec, bool reportUnknownSymbol) {
   byte = strtol(spec, &invalid, base);
 
   if(spec != invalid) {
+
+    if(byte >= 0xfc) {
+      fprintf(stderr, "error: '$%02X': reserved slot (use $40-$FB only)\n", byte);
+      goto done;
+    }
+    
     *key = byte;
     result = true;
     goto done;
@@ -358,6 +405,10 @@ bool Key_parse(uint8_t *key, char* spec, bool reportUnknownSymbol) {
     }
   }
 
+  if(StringList_has_definition(spec)) {
+    return Key_parse(key, StringList_get_definition(spec)->value, reportUnknownSymbol);
+  }  
+  
   if(!result && reportUnknownSymbol) {
     fprintf(stderr, "error: '%s': unknown key name\n", spec);
   }
