@@ -3,9 +3,6 @@
 
 #include <stdio.h>
 
-#define KEYMAN64_VID 0x1d50
-#define KEYMAN64_PID 0x60e9
-
 void version(void);
 void usage(void);
 void keys(void);
@@ -28,4 +25,7 @@ bool Command_parse(Command* self, char* spec);
 void Command_write(Command *self, FILE* out);
 void Command_print(Command *self, FILE* out);
 
+void State_write(State* self, FILE* out);
+bool State_fetch(State* self);
+
 #endif // KEYMAN64_H
